Mycroft Holmes, Sherlock's elder brother, was a government official who
specialized in taking together facts from a variety of disparate sources and
putting together the best course of government action. His deductive skills
and logical reasoning abilities exceeded even those of Sherlock. Mycroft was
concerned more with the "big picture" than with the details of particular
cases. As such, the role of mycroft_assess within the sherlock
causal segmentation framework is to evaluate the population-level causal
effects that would result from following the course of action (i.e., dynamic
treatment) prescribed by Sherlock and Watson. For mycroft_assess to
work, both sherlock_calculate and watson_segment
must be called in sequence to evaluate the segmentation case and assign a
treatment decision to segments.
1 2 | mycroft_assess(data_from_advising, param_type = c("hte", "ote"),
est_type = c("onestep"))
|
data_from_advising |
A |
param_type |
A
|
est_type |
A
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.